diff --git a/list-common.sh b/list-common.sh
index 673576e..490665e 100644
--- a/list-common.sh
+++ b/list-common.sh
@@ -34,6 +34,7 @@ buildignore patterns-gnome-gnome_multimedia_opt
buildignore patterns-gnome-gnome_imaging_opt
buildignore patterns-gnome-gnome_office_opt
buildignore patterns-base-apparmor_opt
+buildignore patterns-base-documentation
buildignore patterns-base-enhanced_base_opt
buildignore patterns-fonts-fonts_opt
buildignore patterns-desktop-imaging_opt
@@ -244,10 +245,11 @@ install quota
install xfsdump
install xfsprogs
+install pciutils
+
# This was previously recommended by rest_cd_core
install adaptec-firmware
install atmel-firmware
-install b43-fwcutter
install bluez-firmware
install crda
install dmidecode
diff --git a/list-gnome.sh b/list-gnome.sh
index 02142a4..6c56a70 100644
--- a/list-gnome.sh
+++ b/list-gnome.sh
@@ -40,6 +40,7 @@ buildignore simple-scan
buildignore ghostscript
buildignore myspell-en_US
buildignore orca
+buildignore patterns-gnome-gnome_games
# gnome-software is a nice software center, but on the live medium only of limited use
buildignore gnome-software
@@ -98,7 +99,6 @@ install alsa-firmware
# Previously required by rest_cd_gnome
installPattern apparmor
-installPattern games
installPattern gnome
installPattern gnome_basis
installPattern gnome_imaging
diff --git a/list-xfce.sh b/list-xfce.sh
index e7fb113..2b8c11c 100644
--- a/list-xfce.sh
+++ b/list-xfce.sh
@@ -14,6 +14,12 @@ buildignore gtk3-immodule-vietnamese
buildignore awesfx
buildignore sbl
buildignore gnome-online-accounts
+buildignore samba
+
+if [ "$distro" = "leap" ]; then
+ # Avoid pipewire. The desktop portal isn't really needed here.
+ buildignore xdg-desktop-portal
+fi
#temp disabled - until build fuxed
buildignore pragha
diff --git a/livecd-leap-gnome.kiwi b/livecd-leap-gnome.kiwi
index 1feba01..f12bd61 100644
--- a/livecd-leap-gnome.kiwi
+++ b/livecd-leap-gnome.kiwi
@@ -129,6 +129,8 @@
+
+
@@ -365,9 +367,9 @@
+
-
@@ -522,6 +524,8 @@
+
+
@@ -575,7 +579,6 @@
-
diff --git a/livecd-leap-kde.kiwi b/livecd-leap-kde.kiwi
index 8a99fc9..64f36f5 100644
--- a/livecd-leap-kde.kiwi
+++ b/livecd-leap-kde.kiwi
@@ -129,6 +129,8 @@
+
+
@@ -365,9 +367,9 @@
+
-
diff --git a/livecd-leap-x11.kiwi b/livecd-leap-x11.kiwi
index 94573f4..193bc9f 100644
--- a/livecd-leap-x11.kiwi
+++ b/livecd-leap-x11.kiwi
@@ -129,6 +129,8 @@
+
+
@@ -365,9 +367,9 @@
+
-
diff --git a/livecd-leap-xfce.kiwi b/livecd-leap-xfce.kiwi
index 5ab636a..0de9439 100644
--- a/livecd-leap-xfce.kiwi
+++ b/livecd-leap-xfce.kiwi
@@ -129,6 +129,8 @@
+
+
@@ -365,9 +367,9 @@
+
-
@@ -441,6 +443,10 @@
+
+
+
+
diff --git a/livecd-openSUSE.changes b/livecd-openSUSE.changes
index c105e20..00dcf43 100644
--- a/livecd-openSUSE.changes
+++ b/livecd-openSUSE.changes
@@ -1,3 +1,40 @@
+-------------------------------------------------------------------
+Tue Dec 12 08:22:23 UTC 2023 - Fabian Vogt
+
+- list-xfce: Drop samba. Not really used but recommended by the pattern
+- list-xfce: Drop xdg-desktop-portal on Leap.
+- Drop qcom FW on non-aarch64 again
+- Only allow passwordless sudo for linux
+
+-------------------------------------------------------------------
+Wed Dec 6 15:58:56 UTC 2023 - Fabian Vogt
+
+- list-common: Drop b43-fwcutter. Only makes sense if there's already
+ a network connection. Keep pciutils though.
+
+-------------------------------------------------------------------
+Wed Dec 6 13:41:48 UTC 2023 - Dominique Leuenberger
+
+- list-common.sh: ignore patterns-base-documentation. This makes
+ the Live CD a little bit smaller again, as it no longer includes
+ + cryptsetup-doc
+ + coreutils-doc (was explicitly ignored already; cleaned up)
+ + bash-doc (was explicitly ignored already; cleaned up)
+ + readline-doc (was explicitly ignored already; cleaned up)
+ + info-std
+ + systemd-doc (was explicitly ignored already; cleaned up)
+
+-------------------------------------------------------------------
+Fri Dec 1 08:02:36 UTC 2023 - Dominique Leuenberger
+
+- list-gnome.sh: no longer install the games pattern. We really run
+ low on space.
+
+-------------------------------------------------------------------
+Wed Nov 29 11:17:40 UTC 2023 - Dominique Leuenberger
+
+- Drop the nvidia/gsp firmware images: they make up > 70MB.
+
-------------------------------------------------------------------
Thu Nov 23 09:22:49 UTC 2023 - Guillaume GARDET
diff --git a/livecd-tumbleweed-gnome.kiwi b/livecd-tumbleweed-gnome.kiwi
index b01541d..998cc48 100644
--- a/livecd-tumbleweed-gnome.kiwi
+++ b/livecd-tumbleweed-gnome.kiwi
@@ -129,6 +129,8 @@
+
+
@@ -365,9 +367,9 @@
+
-
@@ -513,6 +515,8 @@
+
+
@@ -566,7 +570,6 @@
-
diff --git a/livecd-tumbleweed-kde.kiwi b/livecd-tumbleweed-kde.kiwi
index 48f63d7..a6b5cd6 100644
--- a/livecd-tumbleweed-kde.kiwi
+++ b/livecd-tumbleweed-kde.kiwi
@@ -129,6 +129,8 @@
+
+
@@ -365,9 +367,9 @@
+
-
diff --git a/livecd-tumbleweed-x11.kiwi b/livecd-tumbleweed-x11.kiwi
index 0adc561..853bab8 100644
--- a/livecd-tumbleweed-x11.kiwi
+++ b/livecd-tumbleweed-x11.kiwi
@@ -129,6 +129,8 @@
+
+
@@ -365,9 +367,9 @@
+
-
diff --git a/livecd-tumbleweed-xfce.kiwi b/livecd-tumbleweed-xfce.kiwi
index 1a37b64..cf2bce0 100644
--- a/livecd-tumbleweed-xfce.kiwi
+++ b/livecd-tumbleweed-xfce.kiwi
@@ -129,6 +129,8 @@
+
+
@@ -365,9 +367,9 @@
+
-
@@ -441,6 +443,8 @@
+
+
diff --git a/config.sh b/config.sh
index 2bc47ac..a67bbe6 100644
--- a/config.sh
+++ b/config.sh
@@ -115,8 +115,14 @@ rm -rf /usr/share/doc/packages/*
# Save more than 150 MiB by removing this, not very useful for lives
rm -rf /lib/firmware/{liquidio,netronome,qed,mrvl,mellanox,cypress,dpaa2,bnx2x,cxgb4}
-# Keep some qcom firmware for Lenovo X13s and delete others (save ~50MiB)
-rm -rf /lib/firmware/qcom/{apq8016,apq8096,qcm2290,qrb4210,sdm845,sm8250,venus*,vpu*}
+if [ "$(arch)" == "aarch64" ]; then
+ # Keep some qcom firmware for Lenovo X13s and delete others (save ~50MiB)
+ rm -rf /lib/firmware/qcom/{apq8016,apq8096,qcm2290,qrb4210,sdm845,sm8250,venus*,vpu*}
+else
+ rm -rf /lib/firmware/qcom
+fi
+# the new, optional nvidia gsp firmware blobs are huge - ~ 70MB
+find /lib/firmware/nvidia -name gsp | xargs -r rm -rf
# The gems are unpackaged already, no need to store them twice
@@ -143,11 +149,10 @@ zypper --non-interactive rm -u skelcd-openSUSE || :
zypper rl $(seq 1 $(zypper ll | wc -l))
#======================================
-# /etc/sudoers hack to fix #297695
+# sudoers hack to fix #297695
# (Installation Live CD: no need to ask for password of root)
#--------------------------------------
-sed -i -e "s/ALL ALL=(ALL) ALL/ALL ALL=(ALL) NOPASSWD: ALL/" /etc/sudoers
-chmod 0440 /etc/sudoers
+echo "linux ALL=(ALL) NOPASSWD: ALL" > /etc/sudoers.d/50-livecd
/usr/sbin/useradd -m -u 1000 linux -c "Live-CD User" -p ""